@@ -558,15 +558,12 @@ class SegNet(pl.LightningModule):
                 loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.LongTensor))
             else:
                 loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.FloatTensor))
+            self.log({'val/loss' : loss})
+            self.log({'val/acc' : acc})
+            self.log({'val/auc' : auc})
+            log_dict = {'val/loss' : loss, 'val/acc' : acc, 'val/auc' : auc}
+            return {"progress_bar" : log_dict}
 
-            return {'loss' : loss, 'acc' : acc, 'auc' : auc}
-
-    def validation_epoch_end(self, outputs):
-        loss = torch.stack([x["loss"] for x in outputs]).mean()
-        acc = torch.stack([x["acc"] for x in outputs]).mean()
-        auc = torch.stack([x["auc"] for x in outputs]).mean()
-        log_dict = {'val/loss' : loss, 'val/acc' : acc, 'val/auc' : auc}
-        return {"log": log_dict, "progress_bar" : log_dict}
 
     def predict_step(self, pred_batch, batch_idx, dataloader_idx=0):
         x_batch, y_batch = pred_batch
