@@ -1,4 +1,4 @@
-from astrape.models.models_lightning import MLP, ContractingMLP, CustomMLP, VGG, UNet
+from astrape.models.models_lightning import MLP, ContractingMLP, CustomMLP, VGG, UNet, PixelCNN
 from astrape.models.model_buildingblocks import DoubleConv, Down, Up
 from astrape.utilities.utils_lightning import set_default_parameters
 
@@ -7,6 +7,7 @@ __all__ = [
     'MLP', 
     'ContractingMLP', 
     'CustomMLP', 
+    'PixelCNN',
     'VGG', 
     'UNet', 
     'DoubleConv', 
