@@ -5,7 +5,7 @@ import torch
 import torch.nn as nn
 from astrape.utilities.utils_lightning import set_default_parameters
 from astrape.utilities.utils import rearrange_dims
-from astrape.base.model_base import BaseNet, ConvNet
+from astrape.base.model_base import BaseNet, ConvNet, SegNet
 from typing import Union, List, Dict, Any, Optional, cast, Tuple
 from astrape.exceptions.exceptions import *
 from astrape.models.model_buildingblocks import Down, DoubleConv, Up
@@ -1019,7 +1019,7 @@ class _UNet(nn.Module):
             xi[-1] = layer(xi[-1], xi[-2 - i])
         return self.layers[-1](xi[-1])
 
-class UNet(ConvNet):
+class UNet(SegNet):
     def __init__(
         self,
         dims : Union[int, Tuple[int]],
@@ -1146,7 +1146,7 @@ class _PixelCNN(nn.Module):
         c = nn.ReLU()(c)
         return c
 
-class PixelCNN(ConvNet):
+class PixelCNN(SegNet):
     def __init__(
         self,
         dims : Union[int, Tuple[int]],
