@@ -606,6 +606,31 @@ class BaseProject:
 
             sampling_idx = np.random.choice(range(imgs.shape[0]), size=n_data)
             imgs_to_show = imgs[sampling_idx]
+            if len(self.y.shape) > 1: #segmentation
+                self.project_logger.add_images('sample_images', imgs_to_show, dataformats=dataformats)
+                dataformats_without_N = dataformats.replace("N","")
+                for i in range(n_data):
+                    self.project_logger.add_image(
+                        f"sample_images/image_{i}",
+                        imgs_to_show[i],
+                        dataformats=dataformats_without_N
+                    )
+                rows = int(math.sqrt(n_data)) + 1
+                cols = int(math.sqrt(n_data))
+                fig = plt.figure(figsize=(5*rows, 5*cols))
+                idx = 0
+                for i in range(1, rows+1):
+                    for j in range(1, cols+1):
+                        idx += 1
+                        if idx < n_data + 1:
+                            img = fig.add_subplot(rows, cols, idx)
+                            if len(self.dims) > 2:
+                                dims_imshow = rearrange_dims(self.dims, in_format=dataformats, dataformats="NHWC")
+                            img.imshow(imgs_to_show[idx-1].reshape(dims_imshow))
+                            img.set_title(f'Image # {idx-1}')
+                plt.show()
+                plt.savefig(f"{img_dir}/image_samples.png")
+                return None
             labels_to_show = self.y[sampling_idx]
             # for logging
             self.project_logger.add_images('sample_images', imgs_to_show, dataformats=dataformats)
